from _typeshed import Incomplete

import gdb

class MissingDebugHandler:
    @property
    def name(self) -> str: ...
    enabled: bool
    def __init__(self, name: str) -> None: ...
    def __call__(self, objfile: gdb.Objfile) -> bool | str | None: ...

def register_handler(locus: Incomplete | None, handler: MissingDebugHandler, replace: bool = False) -> None: ...
